.. Superdesk documentation master file, created by
   sphinx-quickstart on Wed Aug 31 18:02:55 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================================
Welcome to Superdesk documentation
==================================
*At Sourcefabric, we develop open-source software for journalism*

.. image:: _static/logo.svg
   :width: 400px
   :alt: Superdesk
   :class: floatinglogo

Welcome. This is the home of Superdesk technical documentation. You will learn
here mainly about the Superdesk server application.

For technical documentation on the Superdesk client web application, have a look
`here <https://github.com/superdesk/superdesk-client-core>`_.

.. note::

    Looking for non-technical user documentation?

    We've got you covered. Check out the `User Manual <https://www.superdesk.org/uploads/superdeskmastermanual.pdf>`_.

First steps
-----------

New to Superdesk? This is the best place to start. Here you will get the big picture of
how the Superdesk server works.

* `Installation <https://www.superdesk.org/news/installing-superdesk-publisher>`_

.. _reference:

Reference
---------

Check out this technical reference to understand in detail how the Superdesk server
works and can be developed further.

.. toctree::
    :maxdepth: 2

    architecture
    publish
    ingest
    spellchecking
    ai
    settings
    schema
    content-types
    contentapi
    editor
    auth_server
    production_api
    video_server
    extending
    authentication
    cli
    signals
    testing
    notifications

Additional topics
-----------------

Learn about other important core aspects of working with the Superdesk server.

.. toctree::
    :maxdepth: 2

    cache
    expiry
    api

Contributing
------------

Interested in contributing to the Superdesk project? Here you can learn how to give us
a hand by helping us to either improve this documentation or writing some code.

.. toctree::
    :maxdepth: 2

    contributing
